# instanzio un oggetto simulatore
set ns [new Simulator]

# introduco l'utilizzo di pacchetti 'rtProtoDV' legati al protocollo di routing
$ns rtproto DV

# definisco il tipo di simulazione
# !! e' solo per la versione di ns2 installata in laboratorio EDA
$ns set cosim_type 0

# creo un file per NAM con le statistiche
set nf [open out.nam w]
$ns namtrace-all $nf

# genero un file per la traccia di tutti i pacchetti che circolano in rete
set traceFile [open out.tr w]
$ns trace-all $traceFile

# per monitorare un unico link anziche' tutta la rete
# $ns trace-queue $n0 $1 $traceFile 

# definisco la procedura di chiusura
# 1. invoca la fine della simulazione
# 2. chiude le statistiche
# 3. lancia NAM
# 4. termina la simulazione
proc finish {} {
	global ns nf traceFile
	$ns flush-trace
	close $nf
	close $traceFile
	exec nam out.nam &
	exit 0
}

# descrivo la topologia della rete
# creo i nodi mediante array e cicli
for {set i 0} {$i < 7} {incr i} {
	set n($i) [$ns node]
}

# tipo link  // da // a // capacita' // ritardo // coda router  
# creo i link mediante array e cicli
for {set i 0} {$i < 7} {incr i} {
	$ns duplex-link $n($i) $n([expr ($i+1)%7]) 1Mb 10ms DropTail
}


# nel modello ISO/OSI e in base alla terminologia TCP/IP
# nodi : livello 3 (trasmissione/ricezione di pacchetti e routing)
# link : livello 2
# host : livello 4 (trasporto) + livello applicazione 
#         (creazione/ricezione di dati)

# creo del traffico tra il nodo 0 ed il nodo 3

# creo un agente UDP su n0 
set udp0 [new Agent/UDP]
$ns attach-agent $n(0) $udp0
# creo un'applicazione sopra l'agente UDP di n0
# sorgente di traffico Constant BitRate (CBR) con pacchetti
# da 500 byte ogni 5ms
set cbr0 [new Application/Traffic/CBR]
$cbr0 set packetSize_ 500
$cbr0 set interval_ 0.005
$cbr0 attach-agent $udp0
#--

# creo un agente collettore di pacchetti su n3 
set null0 [new Agent/Null]
$ns attach-agent $n(3) $null0
#--

# connetto gli agenti 
# n.b. livello 4 host-to-host, non e' necessario che 2 i rispettivi nodi siano 
# fisicamente adiacenti
$ns connect $udp0 $null0

# con 'at' inserisco gli eventi di simulazione

# imposto la chiamata alla funzione di chiusura al 5' secondo di simulazione
$ns at 5.0 "finish"

# programmo l'accensione e lo spegnimento della sorgente CBR
$ns at 0.5 "$cbr0 start"
$ns at 4.5 "$cbr0 stop"

# introduco un malfunzionamento tra n1 e n2 dall'istante 1s all'istante 2s
$ns rtmodel-at 1.0 down $n(1) $n(2)
$ns rtmodel-at 2.0 up $n(1) $n(2)

# lancio la simulazione
$ns run 
